@@ -13,6 +13,8 @@ swap_class <- function(x, new_class) {
 }
 
 setClassUnion("NULLorCharacter", c("NULL", "character"))
+setClassUnion("NULLorNumeric", c("NULL", "numeric"))
+setClassUnion("NULLorList", c("NULL", "list"))
 
 #' tinytable S4 class
 #'
@@ -22,38 +24,38 @@ setClass(
   Class = "tinytable",
   slots = representation(
     body = "character",
+    body_data = "data.frame",
+    body_index = "numeric",
     bootstrap_class = "character",
     bootstrap_css_rule = "character",
-    caption = "character",
+    caption = "NULLorCharacter",
     css = "data.frame",
     data = "data.frame",
+    group_data_i = "data.frame",
+    group_data_j = "data.frame",
     group_index_i = "numeric",
-    group_n_i = "numeric",
-    group_n_j = "numeric",
+    height = "NULLorNumeric",
     id = "character",
     lazy_finalize = "list",
     lazy_format = "list",
-    lazy_group = "list",
     lazy_plot = "list",
     lazy_style = "list",
     lazy_theme = "list",
     names = "NULLorCharacter",
     ncol = "numeric",
     nhead = "numeric",
-    notes = "list",
+    notes = "NULLorList",
     nrow = "numeric",
     output = "character",
     output_dir = "character",
-    placement = "character",
+    placement = "NULLorCharacter",
     portable = "logical",
     style = "data.frame",
     style_caption = "list",
     style_notes = "list",
-    table_dataframe = "data.frame",
-    table_input = "data.frame",
     table_string = "character",
     theme = "list",
-    width = "numeric",
+    width = "NULLorNumeric",
     width_cols = "numeric"
   )
 )
@@ -65,29 +67,42 @@ setClass(
 setMethod(
   "initialize",
   "tinytable",
-  function(.Object,
-           data = data.frame(),
-           table_input = data.frame(),
-           caption = NULL,
-           notes = NULL,
-           theme = list("default"),
-           placement = NULL,
-           width = NULL) {
+  function(
+    .Object,
+    data = data.frame(),
+    caption = NULL,
+    notes = NULL,
+    theme = list("default"),
+    body_data = data.frame(),
+    placement = NULL,
+    width = NULL,
+    height = NULL
+  ) {
     # explicit
     .Object@data <- data
-    .Object@table_dataframe <- table_input
+    .Object@body_data <- body_data
     .Object@theme <- theme
+    .Object@placement <- placement
+    .Object@caption <- caption
+    .Object@width <- width
+    .Object@notes <- notes
+    .Object@height <- height
+
     # dynamic
     .Object@nrow <- nrow(.Object@data)
     .Object@ncol <- ncol(.Object@data)
     .Object@nhead <- if (is.null(colnames(data))) 0 else 1
-    .Object@group_n_i <- 0
-    .Object@group_n_j <- 0
     .Object@names <- if (is.null(colnames(data))) {
       character()
     } else {
       colnames(data)
     }
+
+    # empty
+    .Object@group_data_i <- data.frame()
+    .Object@group_data_j <- data.frame()
+    .Object@body_index <- numeric(0)
+    .Object@group_index_i <- numeric(0)
     .Object@id <- get_id("tinytable_")
     .Object@output <- "tinytable"
     .Object@output_dir <- getwd()
@@ -95,11 +110,7 @@ setMethod(
     .Object@portable <- FALSE
     .Object@style <- data.frame()
     .Object@lazy_theme <- list()
-    # conditional: allows NULL user input
-    if (!is.null(placement)) .Object@placement <- placement
-    if (!is.null(caption)) .Object@caption <- caption
-    if (!is.null(width)) .Object@width <- width
-    if (!is.null(notes)) .Object@notes <- notes
+
     return(.Object)
   }
 )
@@ -148,7 +159,9 @@ setReplaceMethod(
   signature = "tinytable",
   definition = function(x, value) {
     # Issue #306
-    if (length(value) == 0) value <- NULL
+    if (length(value) == 0) {
+      value <- NULL
+    }
     if (!is.null(value)) {
       assert_character(value, len = length(x@names))
     } else {
@@ -169,7 +182,9 @@ setReplaceMethod(
   signature = "tinytable",
   definition = function(x, value) {
     # Issue #306
-    if (length(value) == 0) value <- NULL
+    if (length(value) == 0) {
+      value <- NULL
+    }
     if (!is.null(value)) {
       assert_character(value, len = length(x@names))
     } else {
@@ -233,10 +248,11 @@ setGeneric(
 #' @inheritParams tt
 #' @keywords internal
 setGeneric(
-  name = "group_eval",
-  def = function(x, ...) standardGeneric("group_eval")
+  name = "group_eval_j",
+  def = function(x, ...) standardGeneric("group_eval_j")
 )
 
+
 #' Apply final settings to a tinytable
 #'
 #' @inheritParams tt
