@@ -10,17 +10,34 @@ theme_default <- function(x, ...) {
 
   if (isTRUE(x@output %in% c("html", "typst"))) {
     col <- if (x@output == "typst") "black" else "#d3d8dc"
-    bc <- if (length(x@bootstrap_class) == 0) "table table-borderless" else
+    bc <- if (length(x@bootstrap_class) == 0) {
+      "table table-borderless"
+    } else {
       x@bootstrap_class
-    # top
-    x <- style_tt(
-      x,
-      bootstrap_class = bc,
-      i = -x@nhead + 1,
-      line = "t",
-      line_color = col,
-      line_width = 0.1
-    )
+    }
+    # bootstrap class
+    x <- style_tt(x, bootstrap_class = bc)
+
+    # top border
+    if (x@output == "html" && length(x@names) == 0) {
+      # For HTML with no column names, apply border to the first data row
+      x <- style_tt(
+        x,
+        i = 1,
+        line = "t",
+        line_color = col,
+        line_width = 0.1
+      )
+    } else {
+      # For other cases, use the standard header position
+      x <- style_tt(
+        x,
+        i = -x@nhead + 1,
+        line = "t",
+        line_color = col,
+        line_width = 0.1
+      )
+    }
     # mid
     if (length(x@names) > 0) {
       x <- style_tt(
