@@ -1,7 +1,10 @@
 theme_grid <- function(x, ...) {
   fn <- theme_placement_factory(
     horizontal = get_option("tinytable_theme_default_horizontal", "c"),
-    latex_float = get_option("tinytable_theme_placement_latex_float", default = NULL)
+    latex_float = get_option(
+      "tinytable_theme_placement_latex_float",
+      default = NULL
+    )
   )
   x <- style_tt(x, finalize = fn)
 
@@ -18,8 +21,10 @@ theme_grid <- function(x, ...) {
     return(table)
   }
 
-  x <- style_tt(x,
-    tabularray_inner = "hlines, vlines,", finalize = fn,
+  x <- style_tt(
+    x,
+    tabularray_inner = "hlines, vlines,",
+    finalize = fn,
     bootstrap_class = "table table-bordered"
   )
   return(x)
