@@ -7,7 +7,6 @@ theme_dictionary <- list(
   "revealjs" = theme_revealjs,
   "resize" = theme_resize,
   "rotate" = theme_rotate,
-  "spacing" = theme_spacing,
   "striped" = theme_striped,
   "tabular" = theme_tabular,
   "void" = theme_void
@@ -29,7 +28,6 @@ theme_dictionary <- list(
 #'   + "revealjs": Tables optimized for Reveal.js presentations with light/dark theme support
 #'   + "rotate": Rotate a LaTeX or Typst table.
 #'   + "resize": Scale a LaTeX `tinytable` to fit the `width` argument.
-#'   + "spacing": Draw more compact or airy tables.
 #'   + "striped": Grey stripes on alternating rows
 #'   + "tabular": Remove table environment (LaTeX) or Javascript/CSS (HTML)
 #'   + "void": No rules
@@ -81,11 +79,6 @@ theme_dictionary <- list(
 #'   - Typst: In Quarto documents, rotation does not work because Quarto takes over the figure environment.
 #'   - LaTeX: In Quarto documents, captions must be specified using the `caption` argument in `tt()` rather than via Quarto chunk options.
 #'
-#' spacing
-#'
-#' + `rowsep`: Row spacing
-#' + `colsep`: Column spacing
-#'
 #' @examples
 #' library(tinytable)
 #'
@@ -115,6 +108,11 @@ theme_tt <- function(x, theme, ...) {
   td <- theme_dictionary
   na <- unique(sort(names(td)))
   assert_choice(theme, na)
+  if (identical(theme, "void")) {
+    if (isTRUE(nrow(x@style$line) > 0)) {
+      x@style$line <- NA
+    }
+  }
   fn <- td[[theme]]
   out <- list(list(fn, list(...)))
   x@lazy_theme <- c(x@lazy_theme, out)
