@@ -26,7 +26,9 @@ ttempdir <- function() {
   d <- tempdir()
   d <- file.path(d, "tinytable")
   # start fresh
-  if (dir.exists(d)) unlink(d, recursive = TRUE)
+  if (dir.exists(d)) {
+    unlink(d, recursive = TRUE)
+  }
   dir.create(d)
   return(d)
 }
@@ -110,3 +112,27 @@ lines_insert <- function(old, new, regex, position = "before") {
   out <- paste(lines, collapse = "\n")
   return(out)
 }
+
+
+# strip ANSI from `tibble`/`pillar`; keep for markdown
+render_fansi <- function(x) {
+  tab <- x@body_data
+  if (isTRUE(check_dependency("fansi"))) {
+    for (col in seq_along(tab)) {
+      if (isTRUE(x@output == "html")) {
+        tab[[col]] <- as.character(fansi::to_html(tab[[col]], warn = FALSE))
+      } else if (isTRUE(!x@output %in% c("markdown", "dataframe"))) {
+        tab[[col]] <- as.character(fansi::strip_ctl(tab[[col]]))
+      }
+    }
+  }
+  x@body_data <- tab
+  return(x)
+}
+
+
+rbind_nocol <- function(...) {
+  dflist <- list(...)
+  out <- lapply(list(...), function(k) stats::setNames(k, seq_len(ncol(k))))
+  do.call(rbind, out)
+}
