@@ -1,6 +1,8 @@
 source("helpers.R")
 
-if (!is_local) exit_file("Run on Vincent's machine")
+if (!is_local) {
+  exit_file("Run on Vincent's machine")
+}
 
 x <- cbind(mtcars[1, ], mtcars[1, ])
 dest_dir <- tempdir()
